"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
class HistoryQuery extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.state = {
            editable: false,
        };
        this.editField = null;
    }
    render() {
        const displayName = this.props.label ||
            this.props.operationName ||
            this.props.query
                ?.split('\n')
                .filter(line => line.indexOf('#') !== 0)
                .join('');
        const starIcon = this.props.favorite ? '\u2605' : '\u2606';
        return (<li className={this.state.editable ? 'editable' : undefined}>
        {this.state.editable ? (<input type="text" defaultValue={this.props.label} ref={c => {
            this.editField = c;
        }} onBlur={this.handleFieldBlur.bind(this)} onKeyDown={this.handleFieldKeyDown.bind(this)} placeholder="Type a label"/>) : (<button className="history-label" onClick={this.handleClick.bind(this)}>
            {displayName}
          </button>)}
        <button onClick={this.handleEditClick.bind(this)} aria-label="Edit label">
          {'\u270e'}
        </button>
        <button className={this.props.favorite ? 'favorited' : undefined} onClick={this.handleStarClick.bind(this)} aria-label={this.props.favorite ? 'Remove favorite' : 'Add favorite'}>
          {starIcon}
        </button>
      </li>);
    }
    handleClick() {
        this.props.onSelect(this.props.query, this.props.variables, this.props.operationName, this.props.label);
    }
    handleStarClick(e) {
        e.stopPropagation();
        this.props.handleToggleFavorite(this.props.query, this.props.variables, this.props.operationName, this.props.label, this.props.favorite);
    }
    handleFieldBlur(e) {
        e.stopPropagation();
        this.setState({ editable: false });
        this.props.handleEditLabel(this.props.query, this.props.variables, this.props.operationName, e.target.value, this.props.favorite);
    }
    handleFieldKeyDown(e) {
        if (e.keyCode === 13) {
            e.stopPropagation();
            this.setState({ editable: false });
            this.props.handleEditLabel(this.props.query, this.props.variables, this.props.operationName, e.currentTarget.value, this.props.favorite);
        }
    }
    handleEditClick(e) {
        e.stopPropagation();
        this.setState({ editable: true }, () => {
            if (this.editField) {
                this.editField.focus();
            }
        });
    }
}
exports.default = HistoryQuery;
//# sourceMappingURL=HistoryQuery.jsx.map