"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const prop_types_1 = __importDefault(require("prop-types"));
function tokenToURL(token) {
    if (token.type !== 'string') {
        return;
    }
    const value = token.string
        .slice(1)
        .slice(0, -1)
        .trim();
    try {
        const location = window.location;
        return new URL(value, location.protocol + '//' + location.host);
    }
    catch (err) {
        return;
    }
}
function isImageURL(url) {
    return /(bmp|gif|jpeg|jpg|png|svg)$/.test(url.pathname);
}
class ImagePreview extends react_1.default.Component {
    constructor() {
        super(...arguments);
        this._node = null;
        this.state = {
            width: null,
            height: null,
            src: null,
            mime: null,
        };
    }
    static shouldRender(token) {
        const url = tokenToURL(token);
        return url ? isImageURL(url) : false;
    }
    componentDidMount() {
        this._updateMetadata();
    }
    componentDidUpdate() {
        this._updateMetadata();
    }
    render() {
        let dims = null;
        if (this.state.width !== null && this.state.height !== null) {
            let dimensions = this.state.width + 'x' + this.state.height;
            if (this.state.mime !== null) {
                dimensions += ' ' + this.state.mime;
            }
            dims = <div>{dimensions}</div>;
        }
        return (<div>
        <img onLoad={() => this._updateMetadata()} ref={node => {
            this._node = node;
        }} src={tokenToURL(this.props.token)?.href}/>
        {dims}
      </div>);
    }
    _updateMetadata() {
        if (!this._node) {
            return;
        }
        const width = this._node.naturalWidth;
        const height = this._node.naturalHeight;
        const src = this._node.src;
        if (src !== this.state.src) {
            this.setState({ src });
            fetch(src, { method: 'HEAD' }).then(response => {
                this.setState({
                    mime: response.headers.get('Content-Type'),
                });
            });
        }
        if (width !== this.state.width || height !== this.state.height) {
            this.setState({ height, width });
        }
    }
}
exports.ImagePreview = ImagePreview;
ImagePreview.propTypes = {
    token: prop_types_1.default.any,
};
//# sourceMappingURL=ImagePreview.jsx.map