"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
class ToolbarMenu extends react_1.default.Component {
    constructor(props) {
        super(props);
        this._node = null;
        this._listener = null;
        this.handleOpen = e => {
            preventDefault(e);
            this.setState({ visible: true });
            this._subscribe();
        };
        this.state = { visible: false };
    }
    componentWillUnmount() {
        this._release();
    }
    render() {
        const visible = this.state.visible;
        return (<a className="toolbar-menu toolbar-button" onClick={this.handleOpen.bind(this)} onMouseDown={preventDefault} ref={node => {
            if (node) {
                this._node = node;
            }
        }} title={this.props.title}>
        {this.props.label}
        <svg width="14" height="8">
          <path fill="#666" d="M 5 1.5 L 14 1.5 L 9.5 7 z"/>
        </svg>
        <ul className={'toolbar-menu-items' + (visible ? ' open' : '')}>
          {this.props.children}
        </ul>
      </a>);
    }
    _subscribe() {
        if (!this._listener) {
            this._listener = this.handleClick.bind(this);
            document.addEventListener('click', this._listener);
        }
    }
    _release() {
        if (this._listener) {
            document.removeEventListener('click', this._listener);
            this._listener = null;
        }
    }
    handleClick(e) {
        if (this._node !== e.target) {
            e.preventDefault();
            this.setState({ visible: false });
            this._release();
        }
    }
}
exports.ToolbarMenu = ToolbarMenu;
exports.ToolbarMenuItem = ({ onSelect, title, label, }) => {
    return (<li onMouseOver={e => {
        e.currentTarget.className = 'hover';
    }} onMouseOut={e => {
        e.currentTarget.className = '';
    }} onMouseDown={preventDefault} onMouseUp={onSelect} title={title}>
      {label}
    </li>);
};
function preventDefault(e) {
    e.preventDefault();
}
//# sourceMappingURL=ToolbarMenu.jsx.map