"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const prop_types_1 = __importDefault(require("prop-types"));
function hasProps(child) {
    if (!child || typeof child !== 'object' || !('props' in child)) {
        return false;
    }
    return true;
}
class ToolbarSelect extends react_1.default.Component {
    constructor(props) {
        super(props);
        this._node = null;
        this._listener = null;
        this.handleOpen = (e) => {
            preventDefault(e);
            this.setState({ visible: true });
            this._subscribe();
        };
        this.state = { visible: false };
    }
    componentWillUnmount() {
        this._release();
    }
    render() {
        let selectedChild;
        const visible = this.state.visible;
        const optionChildren = react_1.default.Children.map(this.props.children, (child, i) => {
            if (!hasProps(child)) {
                return null;
            }
            if (!selectedChild || child.props.selected) {
                selectedChild = child;
            }
            const onChildSelect = child.props.onSelect ||
                (this.props.onSelect &&
                    this.props.onSelect.bind(null, child.props.value, i));
            return (<ToolbarSelectOption {...child.props} onSelect={onChildSelect}/>);
        });
        return (<a className="toolbar-select toolbar-button" onClick={this.handleOpen.bind(this)} onMouseDown={preventDefault} ref={node => {
            this._node = node;
        }} title={this.props.title}>
        {selectedChild?.props.label}
        <svg width="13" height="10">
          <path fill="#666" d="M 5 5 L 13 5 L 9 1 z"/>
          <path fill="#666" d="M 5 6 L 13 6 L 9 10 z"/>
        </svg>
        <ul className={'toolbar-select-options' + (visible ? ' open' : '')}>
          {optionChildren}
        </ul>
      </a>);
    }
    _subscribe() {
        if (!this._listener) {
            this._listener = this.handleClick.bind(this);
            document.addEventListener('click', this._listener);
        }
    }
    _release() {
        if (this._listener) {
            document.removeEventListener('click', this._listener);
            this._listener = null;
        }
    }
    handleClick(e) {
        if (this._node !== e.target) {
            preventDefault(e);
            this.setState({ visible: false });
            this._release();
        }
    }
}
exports.ToolbarSelect = ToolbarSelect;
function ToolbarSelectOption({ onSelect, label, selected, }) {
    return (<li onMouseOver={e => {
        e.currentTarget.className = 'hover';
    }} onMouseOut={e => {
        e.currentTarget.className = '';
    }} onMouseDown={preventDefault} onMouseUp={onSelect}>
      {label}
      {selected && (<svg width="13" height="13">
          <polygon points="4.851,10.462 0,5.611 2.314,3.297 4.851,5.835
    10.686,0 13,2.314 4.851,10.462"/>
        </svg>)}
    </li>);
}
exports.ToolbarSelectOption = ToolbarSelectOption;
ToolbarSelectOption.propTypes = {
    onSelect: prop_types_1.default.func,
    selected: prop_types_1.default.bool,
    label: prop_types_1.default.string,
    value: prop_types_1.default.any,
};
function preventDefault(e) {
    e.preventDefault();
}
//# sourceMappingURL=ToolbarSelect.jsx.map